Crate kcr_canaries_flanksource_com

Crate kcr_canaries_flanksource_com 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the canaries.flanksource.com group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

canaries.flanksource.com/v1

  • Component
  • Topology

Modules

v1